JsUnit Utility Tests

1 1 1
2 2 2
3 3 3 3 3
1 tab2 tabs
There is non-visible and visible markup here that doesn't change the text content
There is an image here and an image link
non visible newlines
<br/>
newline
<hr/>

newline

First paragraph

Second paragraph

First div
Second div

    preformatted
    newline

abc this is not simple

    preformatted block

    preformatted block with nested
    bold tag

this is a paragraph

this is a div